import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { HttpClientModule, HttpClient, HttpHeaders, HttpErrorResponse, HttpResponse } from '@angular/common/http';
import { catchError } from 'rxjs/operators';
import { throwError } from 'rxjs';



@Component({
  selector: 'app-connecting',
  templateUrl: './connecting.component.html',
  styleUrls: ['./connecting.component.css']
})
export class ConnectingComponent implements OnInit {

  constructor( private router: Router, private activatedRoute: ActivatedRoute, private http: HttpClient ) { }

  ngOnInit() {
    this.activatedRoute
      .queryParams
      .subscribe(params => {
          this.doConnect(params);
      });
    }

  buildParams(params: { [key: string]: any;}): string {
    let newparams = new URLSearchParams;
    Object.entries(params).forEach( ([key,value]) => newparams.set(key,value));
    return newparams.toString();
  }

  doConnect(params: { [key: string]: any;}) {
    console.log('doing connection');
    console.log(params);
    let url = params['connecturl'];
    let headers = new HttpHeaders();
    let options = { headers: headers, withCredentials: true};
    let paramstr = this.buildParams(params);
    // let paramstr = this.buildParams(null,identity,this.batchinterface[identity.repr()]);
    this.http.get<HttpResponse<any>>(url+'?'+paramstr,options)
                     .pipe(catchError(this.handleError))
                     .subscribe(resp => this.redirect(resp),
                                error => this.httperror(error));


  }
  redirect(resp: HttpResponse<any>) {
    let loc = resp['location'];
    console.log('updating window location to',loc);
    window.location.assign(loc);
  };


  private httperror(errorstr: string) {
    console.log(errorstr);
  }

  private handleError(error: HttpErrorResponse) {
    if (error.error instanceof ErrorEvent) {
      console.log('instance of ErrorEvent');
      console.log(error);
      // A client-side or network error occurred. Handle it accordingly.
      return throwError("Hmm, that didn't work. If you're using a local connection, please make sure Strudel-TES is running.");
    } else {
      console.log('NOT an instance of ErrorEvent');
      console.log(error);
      return throwError(error.error.message)
      // this.statusMsg.next("There was an error submitting that job. The backend gave me the message: " + error.error.message);

    }
  }

}
